@@ -91,23 +91,7 @@ public class FrameworkLauncher {
 
 		@Override
 		public Enumeration<Permission> elements() {
-			return new Enumeration<Permission>() {
-				int cur = 0;
-
-				@Override
-				public boolean hasMoreElements() {
-					return cur < 1;
-				}
-
-				@Override
-				public Permission nextElement() {
-					if (cur == 0) {
-						cur = 1;
-						return allPermission;
-					}
-					throw new NoSuchElementException();
-				}
-			};
+			return Collections.enumeration(Collections.singleton(allPermission));
 		}
 	};
 
@@ -678,9 +662,8 @@ public class FrameworkLauncher {
 	 * clearPrefixedSystemProperties clears System Properties by writing null properties in the targetPropertyMap that match a prefix
 	 */
 	private static void clearPrefixedSystemProperties(String prefix, Map<String, String> targetPropertyMap) {
-		for (@SuppressWarnings("rawtypes")
-		Iterator it = System.getProperties().keySet().iterator(); it.hasNext();) {
-			String propertyName = (String) it.next();
+		for (Object key : System.getProperties().keySet()) {
+			String propertyName = (String) key;
 			if (propertyName.startsWith(prefix) && !targetPropertyMap.containsKey(propertyName)) {
 				targetPropertyMap.put(propertyName, null);
 			}
